# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ..common import objects_pb2 as objects__pb2
from ..common import worker_common_pb2 as worker__common__pb2


class WorkerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Process = channel.stream_unary(
                '/armonik.api.grpc.v1.worker.Worker/Process',
                request_serializer=worker__common__pb2.ProcessRequest.SerializeToString,
                response_deserializer=worker__common__pb2.ProcessReply.FromString,
                )
        self.HealthCheck = channel.unary_unary(
                '/armonik.api.grpc.v1.worker.Worker/HealthCheck',
                request_serializer=objects__pb2.Empty.SerializeToString,
                response_deserializer=worker__common__pb2.HealthCheckReply.FromString,
                )


class WorkerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Process(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HealthCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Process': grpc.stream_unary_rpc_method_handler(
                    servicer.Process,
                    request_deserializer=worker__common__pb2.ProcessRequest.FromString,
                    response_serializer=worker__common__pb2.ProcessReply.SerializeToString,
            ),
            'HealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HealthCheck,
                    request_deserializer=objects__pb2.Empty.FromString,
                    response_serializer=worker__common__pb2.HealthCheckReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'armonik.api.grpc.v1.worker.Worker', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Worker(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Process(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/armonik.api.grpc.v1.worker.Worker/Process',
            worker__common__pb2.ProcessRequest.SerializeToString,
            worker__common__pb2.ProcessReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def HealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.worker.Worker/HealthCheck',
            objects__pb2.Empty.SerializeToString,
            worker__common__pb2.HealthCheckReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
